Static function to performs biexponential transform on all parameters except SSC-W This is verbatim what Wade was using originally
1 2 | ffp_doTransform(f, cols = c(1:5, 7:13), method = c("biexp", "log",
"linear"), fac = 5.4/262143)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.