ffp_plot_classic: Plot a flowFramePlus use base R (pplot)

Description Usage Arguments

View source: R/plots.R

Description

Plot a flowFramePlus use base R (pplot)

Usage

1
2
3
4
5
ffp_plot_classic(self, private, plist = self$plist, blueBackground = FALSE,
  showZero = TRUE, nbin = 501, bandwidth = 0.001,
  cr = blob_color(blueBackground = FALSE), col = "black", nrpoints = 0,
  instrument = c("diva", "influx"), tx = self$plotScales$x,
  ty = self$plotScales$y, plotaxt = T, ticksize = 1, ...)

Arguments

self

this

private

this$private

plist

Which columns to plot on the x and y axes, can override settings made at class instantiation

tx

Scale to apply to x axis

ty

Scale to apply to y axis


leipzig/flowFramePlus documentation built on May 28, 2019, 5:40 a.m.