ffp_transformCols: Member function performs biexponential transform on all...

Description Usage Arguments Details Value

Description

Member function performs biexponential transform on all parameters except SSC-W

Usage

1
ffp_transformCols(self, private, cols, method)

Arguments

private

this$private

cols

Scale to apply to x axis

method

transformation method

f

flowFrame

Details

This function performs biexponential transform on all parameters except SSC-W

Jitter is set to false for biexponential to get reproducible results (otherwise would result in random #)

Value

a transformed flowFrame


leipzig/flowFramePlus documentation built on May 28, 2019, 5:40 a.m.