flowFramePlus: flowFramePlus

Description Usage Arguments Details Examples

Description

flowFramePlus holds transformalization and scale attributes. It is essentially a small wrapper around flowFrame with some logical defaults.

flowSetPlus holds one for more flowFramePlus objects with some logical defaults.

Usage

1
p <- flowFramePlus$new("/projects/AML/data/AML/AML 1/AML 1 De Novo Panel_Tube_001.fcs", plist = c("FSC-H","SSC-H"))
1
1
p <- flowSetPlus$new("/projects/AML/data/AML/AML 1/AML 1 De Novo Panel_Tube_001.fcs", plist = c("FSC-H","SSC-H"))
1
p <- flowSetPlus$plot()

Arguments

ff

A flowFrame object or filepath of an FCS file.

txlist

List, specify transformation to be used on each column index. For example txlist=list("linear"=c(1:4),"biexp"=c(5:12))

ff

A flowFrame object or filepath of an FCS file.

txlist

List, specify transformation to be used on each column index. For example txlist=list("linear"=c(1:4),"biexp"=c(5:12))

Details

$new() starts a new flowFramePlus object, either from an existing flowFrame object or an FCS filepath

You can specify which columns to transform using the following syntax:

1
p <- flowFramePlus$new(x,txlist=list("linear"=c(1:4),"biexp"=c(5:12)))

$new() starts a new flowFramePlus object, either from an existing flowFrame object or an FCS filepath

You can specify which columns to transform using the following syntax:

1
p <- flowFramePlus$new(x,txlist=list("linear"=c(1:4),"biexp"=c(5:12)))

Examples

1
2
3
4
5
ffp<-flowFramePlus$new("/projects/AML/data/AML/AML 1/AML 1 De Novo Panel_Tube_001.fcs")
ffp$plot()
files<-dir(path="/projects/AML/data/AML/",pattern = "*.fcs",recursive = TRUE,include.dirs = TRUE,full.names = TRUE)
fsp<-flowSetPlus$new(files)
fsp$plot(plist=c("FSC-A","Horizon V500-A"))

leipzig/flowFramePlus documentation built on May 28, 2019, 5:40 a.m.