fsp_plot_classic: Plot a flowSetPlus use base R (pplot)

Description Usage Arguments

View source: R/plots.R

Description

Plot a flowSetPlus use base R (pplot)

Usage

1
fsp_plot_classic(self, private, main = NULL, ...)

Arguments

self

this

private

this$private

main

Plot titles

plist

Which columns to plot on the x and y axes, can override settings made at class instantiation

tx

Scale to apply to x axis

ty

Scale to apply to y axis


leipzig/flowFramePlus documentation built on May 28, 2019, 5:40 a.m.