Plot a flowFramePlus use base R (pplot)
1 2 3 4 5 | ffp_plot_classic(self, private, plist = self$plist, blueBackground = FALSE,
showZero = TRUE, nbin = 501, bandwidth = 0.001,
cr = blob_color(blueBackground = FALSE), col = "black", nrpoints = 0,
instrument = c("diva", "influx"), tx = self$plotScales$x,
ty = self$plotScales$y, plotaxt = T, ticksize = 1, ...)
|
self |
this |
private |
this$private |
plist |
Which columns to plot on the x and y axes, can override settings made at class instantiation |
tx |
Scale to apply to x axis |
ty |
Scale to apply to y axis |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.