Description Usage Arguments Details Value
Member function performs biexponential transform on all parameters except SSC-W
1 | ffp_transformCols(self, private, cols, method)
|
private |
this$private |
cols |
Scale to apply to x axis |
method |
transformation method |
f |
flowFrame |
This function performs biexponential transform on all parameters except SSC-W
Jitter is set to false for biexponential to get reproducible results (otherwise would result in random #)
a transformed flowFrame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.