Description Usage Arguments Details Examples
flowFramePlus holds transformalization and scale attributes. It is essentially a small
wrapper around flowFrame with some logical defaults.
flowSetPlus holds one for more flowFramePlus objects with some logical defaults.
1 | p <- flowFramePlus$new("/projects/AML/data/AML/AML 1/AML 1 De Novo Panel_Tube_001.fcs", plist = c("FSC-H","SSC-H"))
|
1 | p <- flowFramePlus$plot()
|
1 |
1 | p <- flowSetPlus$plot()
|
A flowFrame object or filepath of an FCS file.
List, specify transformation to be used on each column index.
For example txlist=list("linear"=c(1:4),"biexp"=c(5:12))
A flowFrame object or filepath of an FCS file.
List, specify transformation to be used on each column index.
For example txlist=list("linear"=c(1:4),"biexp"=c(5:12))
$new() starts a new flowFramePlus object, either from an existing flowFrame object or
an FCS filepath
You can specify which columns to transform using the following syntax:
1 | p <- flowFramePlus$new(x,txlist=list("linear"=c(1:4),"biexp"=c(5:12)))
|
$new() starts a new flowFramePlus object, either from an existing flowFrame object or
an FCS filepath
You can specify which columns to transform using the following syntax:
1 | p <- flowFramePlus$new(x,txlist=list("linear"=c(1:4),"biexp"=c(5:12)))
|
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.