Plot a flowSetPlus use base R (pplot)
1 | fsp_plot_classic(self, private, main = NULL, ...)
|
self |
this |
private |
this$private |
main |
Plot titles |
plist |
Which columns to plot on the x and y axes, can override settings made at class instantiation |
tx |
Scale to apply to x axis |
ty |
Scale to apply to y axis |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.